@@ -39,7 +39,7 @@
         CALL UESTLV(AMIN,AMAX,IDX)
    20 CONTINUE 
 
-      CALL SGLSET( 'LSOFTF', .TRUE. )
+      CALL SGLSET( 'LSOFTF', .FALSE. )
       CALL SWLSET( 'LCMCH', .TRUE. )
       CALL SGRSET( 'STLAT1', 75.0 )
       CALL SGRSET( 'STLAT2', 60.0 )
@@ -84,10 +84,10 @@
         CALL UMPGLB
         CALL SLPVPR( 1 )
 
-        CALL SWPCLS
 
    30 CONTINUE
+      CALL SWPCLS
 
-      CALL SGCLS
+      CALL SGCLS	
 
       END
