@@ -1,5 +1,7 @@
 *-----------------------------------------------------------------------
 *     TOMS OZONE DISTRIBUTION (MONTHLY MEAN CLIMATOLOGY)
+*-----------------------------------------------------------------------
+*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved.
 *-----------------------------------------------------------------------
       PROGRAM XIMG01
 
@@ -27,8 +29,9 @@
       CDSN='tomsclm.dat'
       OPEN(11,FILE=CDSN,FORM='FORMATTED')
 
-      CALL SWLSTX('LWAIT', .FALSE.)
+      CALL SWLSTX('LWAIT', .TRUE.)
       CALL SWLSTX('LWAIT0', .FALSE.)
+      CALL SWLSTX('LALT', .FALSE.)
       CALL SWISTX('IPOSX', 200)
       CALL SWISTX('IPOSY', 200)
       CALL SWISTX('IWIDTH',  800)
