@@ -3,6 +3,9 @@
 *-----------------------------------------------------------------------
       SUBROUTINE SGTXZU(UX,UY,CHARS,RSIZE,IROTA,ICENT,INDEX)
 
+      REAL WXR,WYR,Q2SIZE
+      PARAMETER (WIDE=24)
+
       CHARACTER CHARS*(*)
 
 
@@ -24,6 +27,20 @@
         CALL MSGDMP('E','SGTXZU','TEXT INDEX IS LESS THAN 0.')
       END IF
 
+      CALL STFTRF(UX,UY,VX,VY)
+      CALL STFWTR(VX,VY,WX,WY)
+      CALL STFWTR(VX+RSIZE,VY+RSIZE,WXR,WYR)
+      QSIZE=WXR-WX
+      Q2SIZE=WYR-WY
+
+      IF(Q2SIZE>QSIZE)THEN
+        QSIZE=Q2SIZE
+      END IF
+
+      THETA=RD2R(REAL(IROTA))
+      CT=QSIZE*COS(THETA)
+      ST=QSIZE*SIN(THETA)
+
       CALL SZTXOP(RSIZE,IROTA,ICENT,INDEX)
       CALL SZTXZU(UX,UY,CHARS)
       CALL SZTXCL
