@@ -15,8 +15,8 @@
 #include <cairo.h>
 #include <cairo-ps.h>
 #include <cairo-pdf.h>
-#include <cairo-svg.h> 
- 
+#include <cairo-svg.h>
+
 static DCL_REAL rwxold, rwyold;
 
 #define FACTZ  0.03          /* scaling factor */
@@ -51,16 +51,23 @@ static DCL_REAL rwxold, rwyold;
 #define IFL_SVG   3
 #define IFL_PDF   4
 
-static double linewidth[MAXWDI] = { 1.0, 2.0, 2.0, 3.0, 3.0, 4.0, 4.0, 5.0, 5.0 };
 
+
+//static double linewidth[MAXWDI] = { 1.0, 2.0, 2.0, 3.0, 3.0, 4.0, 4.0, 5.0, 5.0 };
+static double linewidth[MAXWDI] = { 1.0, 1.5, 2.0, 2.5, 3.0, 3.5, 4.0, 4.5, 5.0 };
+
+static int iwidth,iheight;
 static int iwdidz;           /* pen width */
 static int iclidz;           /* pen color index */
 static int iwtroz;           /* direction of frame */
 static int lclatrz = TRUE;          /* type of screen */
 //static int imagewrite = FALSE;          /* (Not) Use Image buffer Surface */
-static int idev_type;         /* type of device 1:Display 2:Files */
+static int idev_type;         /* absolute value of type of device 1:Display 2:Files */
                               /*1:png 2:eps 3:SVG 4:PDF */
-static int wsxwd, wsywd, wsxmnz, wsxmxz, wsymnz, wsymxz;
+static int jdev_type;         /* type of device (landscape or portlait) 1:Display 2:Files */
+                              /*1:png 2:eps 3:SVG 4:PDF */
+static int wsxwd, wsywd, wsxmnz,wsymnz;
+// wsxmxz, , wsymxz;
 static int ixz, iyz, iwz, ihz, ixxz, iyyz, page; /* for image */
 static int irxt,iryt,irxb,iryb,irwidth; /* for Invalidate */
 static int posx, posy, wait_np, wait_op, wait_cl, key, dump, fgbg, sep;
@@ -89,7 +96,7 @@ static int wnd;
 static cairo_t *cr;
 static cairo_surface_t *csr;
 
-//Font 
+//Font
 gchar     *fontfamily;
 PangoFontDescription *font_desc;
 
@@ -107,13 +114,17 @@ static int ifunc, next;
 static int dumpz = FALSE;
 
 /* Post Script A4 Page (Landscape) */
-#define PS_PAGE_WIDTH  595
-#define PS_PAGE_HEIGHT 842
-#define PS_PAGE_OFFSETX 33
-#define PS_PAGE_OFFSETY 46
+static int PS_PAGE_WIDTH  = 595;
+static int PS_PAGE_HEIGHT = 842;
+
+static int iPS_PAGE_WIDTH;
+static int iPS_PAGE_HEIGHT;
+
+static double ipsx=33;
+static double ipsy=46;
 
 static double ddvscale = 1.0;
-static double dlnscale = 1.0;
+static double dlnscale;
 static double offx = 0.0;
 static double offy = 0.0;
 
@@ -126,6 +137,7 @@ static int pngstdout;
 static int ifl;
 
 static cairo_status_t png2stdout(void *, const unsigned char* , unsigned int );
+static void zgcatl(void);
 
 static char fontlist[255] = { 41, 42, 43, 44, 55, 66, 77, 85, 95 };
 
@@ -177,7 +189,7 @@ void zgupdate(int flag)
       update_rect.y = iryb-1;
       update_rect.width  = irxt-irxb+1;
       update_rect.height = iryt-iryb+1;
-    
+
       if (irxb == 0 && irxt == 0 && iryb == 0 && iryt == 0 && flag == 0){
         update_rect.x = 0;
         update_rect.y = 0;
@@ -186,9 +198,9 @@ void zgupdate(int flag)
       }
 
       while (gtk_events_pending()) gtk_main_iteration();
-    
+
       gtk_widget_draw(drawing_area, &update_rect);
-    
+
       irxt = 0;
       irxb = 0;
       iryt = 0;
@@ -305,13 +317,6 @@ static GtkWidget *ZGGDRW(DCL_INT *width, DCL_INT *height)
   GtkWidget * drw;
   GtkWidget *vbox;
 
-  wsxwd  = *width  + 2 * PAD ;  /* window width */
-  wsywd  = *height + 2 * PAD ;  /* window height */
-  wsxmnz = PAD + offx;                /* lower-left  corner */
-  wsymnz = PAD + offy;                /* lower-left  corner */
-  wsxmxz = PAD + *width  - 1 - offx;  /* upper-right corner */
-  wsymxz = PAD + *height - 1 - offy ;  /* upper-right corner */
-  
   gtk_init(0,NULL);
 
   drw = gtk_drawing_area_new();
@@ -371,11 +376,6 @@ static cairo_t *zgcsfc(){
         csr = cairo_ps_surface_create(cout, PS_PAGE_HEIGHT * ddvscale, PS_PAGE_WIDTH * ddvscale );
         cairo_ps_surface_set_eps(csr,TRUE);
       }
-
-      dlnscale = 0.1;
-      offx = PS_PAGE_OFFSETY;
-      offy = PS_PAGE_OFFSETX;
-
       linewidth[0] =  2.0;
       linewidth[1] =  4.0;
       linewidth[2] =  6.0;
@@ -400,10 +400,7 @@ static cairo_t *zgcsfc(){
         sprintf (cout, "%s_%0*d.pdf", dmpfile,dmpdgt, page);
       }
       csr = cairo_pdf_surface_create(cout, PS_PAGE_WIDTH * ddvscale, PS_PAGE_HEIGHT * ddvscale );
-      dlnscale = 0.1;
-      offx = PS_PAGE_OFFSETY;
-      offy = PS_PAGE_OFFSETX;
-      linewidth[0] =  2.0;
+/*      linewidth[0] =  2.0;
       linewidth[1] =  4.0;
       linewidth[2] =  6.0;
       linewidth[3] =  8.0;
@@ -411,7 +408,16 @@ static cairo_t *zgcsfc(){
       linewidth[5] = 11.0;
       linewidth[6] = 12.0;
       linewidth[7] = 13.0;
-      linewidth[8] = 14.0;
+      linewidth[8] = 14.0; */
+/*      linewidth[0] =  1.0;
+      linewidth[1] =  2.0;
+      linewidth[2] =  2.0;
+      linewidth[3] =  3.0;
+      linewidth[4] = 3.0;
+      linewidth[5] = 4.0;
+      linewidth[6] = 4.0;
+      linewidth[7] = 5.0;
+      linewidth[8] = 5.0;*/
     }
   }
 
@@ -444,7 +450,7 @@ static void zgbmcv(int *nx, int *ny, char bmline[], char bitmap[])
 #ifndef WINDOWS
 void zgdopn_(DCL_INT *dev_type,
              DCL_INT *width, DCL_INT *height, DCL_INT *iposx, DCL_INT *iposy, DCL_INT *idmpdgt,
-             DCL_INT *ibgpage,
+             DCL_INT *ibgpage,DCL_REAL *rlwfact,
              DCL_INT *lwait, DCL_INT *lwait0, DCL_INT *lwait1, DCL_INT *lalt , DCL_INT *lstdot,
              DCL_INT *lkey, DCL_INT *ldump, DCL_INT *lwnd, DCL_INT *lfgbg, DCL_INT *lsep, DCL_INT *ifln,
              char cimgfmt[], DCL_REAL *rimgcmp, char clrmap[], char cbmmap[], char file[], char title[]
@@ -452,7 +458,7 @@ void zgdopn_(DCL_INT *dev_type,
 #else
 void ZGDOPN(DCL_INT *dev_type,
             DCL_INT *width, DCL_INT *height, DCL_INT *iposx, DCL_INT *iposy, DCL_INT *idmpdgt,
-            DCL_INT *ibgpage,
+            DCL_INT *ibgpage, DCL_REAL *rlwfact,
             DCL_INT *lwait, DCL_INT *lwait0, DCL_INT *lwait1, DCL_INT *lalt,DCL_INT *lstdot,
             DCL_INT *lkey, DCL_INT *ldump, DCL_INT *lwnd, DCL_INT *lfgbg, DCL_INT *lsep, DCL_INT *ifln,
             char cimgfmt[], DCL_REAL *rimgcmp, char clrmap[], char cbmmap[], char file[], char title[]
@@ -488,17 +494,47 @@ void ZGDOPN(DCL_INT *dev_type,
   fgbg      = *lfgbg;
   sep       = *lsep;
   laltz     = *lalt;
-  idev_type = *dev_type;
+  idev_type = abs(*dev_type);
+  jdev_type = *dev_type;
   wnd       = *lwnd;
   page      = *ibgpage - 1;
 
-
   cfnchr(imgfmt, cimgfmt, 7);
   imgcmp = *rimgcmp;
   dmpdgt = *idmpdgt;
   pngstdout  = *lstdot;
   ifl  = *ifln;
 
+  iwidth = *width;
+  iheight = *height;
+
+  dlnscale = *rlwfact;
+
+  if ((idev_type == IWS_FILE) && ( ifl == IFL_EPS || ifl == IFL_PDF)){
+    if (((PS_PAGE_HEIGHT - ipsy *2) / iwidth) > ((PS_PAGE_WIDTH - ipsx *2 )/ iheight)){
+      iPS_PAGE_WIDTH   = PS_PAGE_WIDTH - ipsx * 2;
+      iPS_PAGE_HEIGHT  = (PS_PAGE_WIDTH - ipsx * 2) * iwidth / iheight;
+      offx = ipsx;
+      offy = ipsy + (PS_PAGE_HEIGHT - ipsy *2 - iPS_PAGE_HEIGHT )/2;
+      if(dlnscale==999.){
+        dlnscale = (DCL_REAL)iPS_PAGE_WIDTH / iwidth ;
+      }
+    }else{
+      iPS_PAGE_WIDTH   = (PS_PAGE_HEIGHT -ipsy*2) * iheight / iwidth;
+      iPS_PAGE_HEIGHT  = PS_PAGE_HEIGHT - ipsy*2;
+      offx = ipsx + (PS_PAGE_WIDTH  - ipsx *2 - iPS_PAGE_WIDTH)/2;
+      offy = ipsy;
+      if(dlnscale==999.){
+        dlnscale = (DCL_REAL)iPS_PAGE_HEIGHT/iheight;
+      }
+    }
+    if( ifl == IFL_EPS ){
+      dlnscale=0.1;
+    }
+  }else{
+    dlnscale = 1.0;
+  }
+
   if (!wnd) {
     wait_np = FALSE;
     wait_op = FALSE;
@@ -514,6 +550,10 @@ void ZGDOPN(DCL_INT *dev_type,
   if (idev_type == IWS_DISP){
     if (drawing_area == NULL) {
       ldclonly = TRUE;
+      wsxwd  = iwidth  + 2 * PAD;  /* window width */
+      wsywd  = iheight + 2 * PAD;  /* window height */
+      wsxmnz = PAD + offx;                /* lower-left  corner */
+      wsymnz = PAD + offy;                /* lower-left  corner */
 #ifndef WINDOWS
       drawing_area = zggdrw_(width,height);
 #else
@@ -521,27 +561,16 @@ void ZGDOPN(DCL_INT *dev_type,
 #endif
     }
   }else if (idev_type == IWS_FILE){
-    if(ifl == IFL_EPS){
-    wsywd = (PS_PAGE_WIDTH  - offx * 2 ) * ddvscale;
-    wsxwd = (PS_PAGE_HEIGHT - offy * 2 ) * ddvscale;
-    wsymnz = offx;
-    wsxmnz = offy;
-    wsymxz = PS_PAGE_WIDTH  - offx;  /* upper-right corner */
-    wsxmxz = PS_PAGE_HEIGHT - offy;  /* upper-right corner */
+    if(ifl == IFL_EPS || ifl == IFL_PDF){
+    wsywd = iPS_PAGE_WIDTH * ddvscale;
+    wsxwd = iPS_PAGE_HEIGHT * ddvscale;
+    wsymnz = offx * ddvscale;
+    wsxmnz = offy * ddvscale;
     }else if(ifl == IFL_PNG || ifl == IFL_SVG ){
-    wsxwd  = *width  + 2 * PAD;  /* window width */
-    wsywd  = *height + 2 * PAD;  /* window height */
+    wsxwd  = iwidth  + 2 * PAD;  /* window width */
+    wsywd  = iheight + 2 * PAD;  /* window height */
     wsxmnz = PAD + offx;                /* lower-left  corner */
     wsymnz = PAD + offy;                /* lower-left  corner */
-    wsxmxz = PAD + *width  -1 - offx;  /* upper-right corner */
-    wsymxz = PAD + *height -1 - offy ;  /* upper-right corner */
-    }else if (ifl == IFL_PDF){
-    wsywd = (PS_PAGE_WIDTH  - offx * 2 ) * ddvscale;
-    wsxwd = (PS_PAGE_HEIGHT - offy * 2 ) * ddvscale;
-    wsymnz = offx;
-    wsxmnz = offy;
-    wsymxz = PS_PAGE_WIDTH  - offx;  /* upper-right corner */
-    wsxmxz = PS_PAGE_HEIGHT - offy;  /* upper-right corner */
     }
   }
 #ifdef WINDOWS
@@ -623,10 +652,8 @@ void ZGDOPN(DCL_INT *dev_type,
      cr =zgcsfc();
   }
 
-  if ((idev_type == IWS_FILE || idev_type == -IWS_FILE) && ifl == IFL_PDF){ 
-    cairo_translate (cr, PS_PAGE_WIDTH * ddvscale / 2.0   , PS_PAGE_HEIGHT * ddvscale / 2.0 );
-    cairo_rotate(cr, -2 * 3.1415926 * 0.25 );
-    cairo_translate (cr, -PS_PAGE_HEIGHT * ddvscale / 2.0 , -PS_PAGE_WIDTH * ddvscale / 2.0 );
+  if (idev_type == IWS_FILE && ifl == IFL_PDF){
+    zgcatl();
 }
 
   rt1 = (double) cx[0].red   / 65535 ;
@@ -670,7 +697,7 @@ void ZGDCLS(void)
         cairo_surface_finish (csr);
         cairo_surface_destroy (csr);
       }
-    } 
+    }
  }
 
 }
@@ -695,7 +722,7 @@ void ZGPOPN(void)
   iwdidz = 1;
   iclidz = 1;
 
-   if (idev_type == IWS_DISP){ 
+   if (idev_type == IWS_DISP){
      cro = cairo_create(csr);
    }else if (idev_type == IWS_FILE){
      if(ifl==IFL_EPS){
@@ -709,13 +736,11 @@ void ZGPOPN(void)
      }else if (ifl == IFL_PDF){
        if(sep){
          cr=zgcsfc();
-         cairo_translate (cr, PS_PAGE_WIDTH * ddvscale / 2.0   , PS_PAGE_HEIGHT * ddvscale / 2.0 );
-         cairo_rotate(cr, -2 * 3.1415926 * 0.25 );
-         cairo_translate (cr, -PS_PAGE_HEIGHT * ddvscale / 2.0 , -PS_PAGE_WIDTH * ddvscale / 2.0 );
+         zgcatl();
        }
        cro = cairo_create(csr);
      }
-  } 
+  }
 
   rt1 =(double) cx[0].red   / 65535;
   gt1 =(double) cx[0].green / 65535;
@@ -723,7 +748,7 @@ void ZGPOPN(void)
 
   cairo_set_source_rgb(cro,rt1,gt1,bt1);
 
-  if (idev_type == IWS_DISP || ( idev_type == IWS_FILE && ifl == IFL_PNG)){ 
+  if (idev_type == IWS_DISP || ( idev_type == IWS_FILE && ifl == IFL_PNG)){
      cairo_rectangle(cro,0.0,0.0,wsxwd,wsywd);
      cairo_fill(cro);
      if(!laltz){
@@ -1111,7 +1136,7 @@ void ZGGTON(DCL_INT *np, DCL_REAL wpx[], DCL_REAL wpy[], DCL_INT *itpat)
 
   cairo_close_path(cr);
   cairo_set_source_rgb(cr,rt1,gt1,bt1);
-// Adhoc Patch for 3 
+// Adhoc Patch for 3
   if ( idev_type == IWS_FILE && ifl == IFL_PDF ){
     cairo_fill_preserve(cr);
     cairo_set_line_width(cr,0.4);
@@ -1179,7 +1204,7 @@ void ZGIDAT(DCL_INT image[], DCL_INT *nlen)
     if (ixxz >= ixz+iwz) {
       ixxz = ixz;
       iyyz = iyyz + 1;
-      if (iyyz % 16 == 0) { 
+      if (iyyz % 16 == 0) {
         fprintf(stderr, ".");
         fflush(stdout);
       }
@@ -1201,7 +1226,7 @@ void ZGICLS(void)
   //  cairo_fill(cr);
   cairo_paint(cr);
 
-  if(!laltz){zgupdate(1);}  
+  if(!laltz){zgupdate(1);}
   fprintf (stderr, " end\n");
 //  cairo_surface_finish(csi);
   cairo_surface_destroy(csi);
@@ -1287,15 +1312,23 @@ void ZGQRCT(DCL_REAL *wsxmn, DCL_REAL *wsxmx, DCL_REAL *wsymn, DCL_REAL *wsymx,
     *fact  = FACTZ;
   }else if (idev_type == IWS_FILE && ( ifl == IFL_EPS || ifl == IFL_PDF)){
     *wsxmn = offy;
-    *wsxmx = PS_PAGE_HEIGHT-offy;
+    *wsxmx = iPS_PAGE_HEIGHT + offy;
     *wsymn = offx;
-    *wsymx = PS_PAGE_WIDTH-offx;
+    *wsymx = iPS_PAGE_WIDTH + offx;
+    *wsxmn = 0;
+    *wsxmx = iPS_PAGE_HEIGHT;
+    *wsymn = 0;
+    *wsymx = iPS_PAGE_WIDTH;
     *fact  = FACTZ;
   }else{
     *wsxmn = offx;
-    *wsxmx = PS_PAGE_WIDTH-offx;
+    *wsxmx = iPS_PAGE_WIDTH+offx;
     *wsymn = offy;
-    *wsymx = PS_PAGE_HEIGHT-offy;
+    *wsymx = iPS_PAGE_HEIGHT+offy;
+    *wsxmn = 0;
+    *wsxmx = iPS_PAGE_WIDTH;
+    *wsymn = 0;
+    *wsymx = iPS_PAGE_HEIGHT;
     *fact  = FACTZ;
   }
 }
@@ -1407,7 +1440,7 @@ void ZGICLR(DCL_INT *image,DCL_INT *nlen)
     if (ixxz >= ixz+iwz) {
       ixxz = ixz;
       iyyz = iyyz + 1;
-      if (iyyz % 16 == 0) { 
+      if (iyyz % 16 == 0) {
         fprintf (stderr,".");
         fflush (stdout);
       }
@@ -1429,6 +1462,8 @@ void ZGCLINI(char clrmap[], DCL_INT *lfgbg)
   FILE *stream;
   int ncolor,n,m,fscanret;
   guint16 rx[MAXCLI], gx[MAXCLI], bx[MAXCLI], rx1, gx1, bx1;
+  double rt1,gt1,bt1;
+  int fgbg;
 
   /* read colormap file */
 
@@ -1446,6 +1481,8 @@ void ZGCLINI(char clrmap[], DCL_INT *lfgbg)
     fscanret=fscanf(stream, "%6hd%6hd%6hd : %s", &rx[n], &gx[n], &bx[n], c);
   fclose(stream);
 
+  fgbg = *lfgbg;
+
   if (fgbg) {
     rx1 = rx[0];
     gx1 = gx[0];
@@ -1459,6 +1496,21 @@ void ZGCLINI(char clrmap[], DCL_INT *lfgbg)
   }
 
   lclatrz = 1;
+/* set colormap */
+  for (n = 0; n < MAXCLI; n++) {
+
+      m = n % ncolor;
+
+      cx[n].red   = rx[m];
+      cx[n].green = gx[m];
+      cx[n].blue  = bx[m];
+  }
+
+  rt1 = (double) cx[0].red   / 65535 ;
+  gt1 = (double) cx[0].green / 65535 ;
+  bt1 = (double) cx[0].blue  / 65535 ;
+
+  cairo_set_source_rgb(cr,rt1,gt1,bt1);
 }
 
 
@@ -1469,3 +1521,10 @@ static cairo_status_t png2stdout(void *closure, const unsigned char* data, unsig
   }
   return CAIRO_STATUS_WRITE_ERROR;
 }
+
+
+static void zgcatl(){
+    cairo_translate (cr, offx+iPS_PAGE_WIDTH * ddvscale / 2.0   , offy+iPS_PAGE_HEIGHT * ddvscale / 2.0 );
+    cairo_rotate(cr, -2 * 3.1415926 * 0.25 );
+    cairo_translate (cr, -iPS_PAGE_HEIGHT * ddvscale / 2.0 , -iPS_PAGE_WIDTH * ddvscale / 2.0 );
+}
