@@ -41,6 +41,9 @@
         IF ((IDI.LT.IML-ID/2 .AND. MOD(IDI,ID).EQ.0)
      +     .OR. IDI.EQ.IML) THEN
           NN=NN+1
+          IF (NN.GT.N) THEN
+            CALL MSGDMP('E','UCXADY','WORKING AREA IS NOT ENOUGH.')
+          END IF
           UX(NN)=I
           WRITE(CH(NN)(1:2),'(I2)') IDI
           CALL CLADJ(CH(NN)(1:2))
@@ -50,8 +53,6 @@
       IF (NN.EQ.0) THEN
         CALL MSGDMP('W','UCXADY','THERE IS NO TICKMARK / LABEL.')
         RETURN
-      ELSE IF (NN.GT.N) THEN
-        CALL MSGDMP('E','UCXADY','WORKING AREA IS NOT ENOUGH.')
       END IF
 
       CALL UZIGET('ICENTX'//CSIDE,ICENT)
