@@ -1,5 +1,5 @@
 *-----------------------------------------------------------------------
-*     Copyright (C) 2000 GFD Dennou Club. All rights reserved.
+*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved.
 *-----------------------------------------------------------------------
       INTEGER FUNCTION IUETON(ZLEV)
 
@@ -24,10 +24,16 @@
           GO TO 10
         END IF
       ELSE
-        DO 20 IT = NT, 1, -1
-          IF (TL1(IT).LE.ZLEV .AND. ZLEV.LE.TL2(IT)) GO TO 30
-   20   CONTINUE
-   30   CONTINUE
+        IF (ZLEV .LT. TL1(1)) THEN
+          IT = 1
+        ELSE IF (ZLEV .GT. TL2(NT)) THEN
+          IT = NT
+        ELSE
+          DO 20 IT = NT, 1, -1
+            IF (TL1(IT).LE.ZLEV .AND. ZLEV.LE.TL2(IT)) GO TO 30
+   20     CONTINUE
+   30     CONTINUE
+        ENDIF
       END IF
       IUETON = IPT(IT)
 
