@@ -1,7 +1,7 @@
 *-----------------------------------------------------------------------
 *     LENZ
 *-----------------------------------------------------------------------
-*     Copyright (C) 2000 GFD Dennou Club. All rights reserved.
+*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved.
 *-----------------------------------------------------------------------
       INTEGER FUNCTION LENZ(C)
 
@@ -16,10 +16,11 @@
 
       N=LEN(C)
 
-   15 LCHAR=N.GE.1 .AND. (C(N:N).EQ.CN .OR. C(N:N).EQ.CS)
-      IF (.NOT.LCHAR) GO TO 10
-        N=N-1
-        GO TO 15
+   15 IF(N.LT.1) GO TO 10
+        LCHAR=(C(N:N).EQ.CN .OR. C(N:N).EQ.CS)
+        IF (.NOT.LCHAR) GO TO 10
+          N=N-1
+          GO TO 15
    10 CONTINUE
 
       LENZ=N
